package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.SysUserPost;
import com.ruoyi.system.domain.loan.LoanApplicationFj;
import org.apache.ibatis.annotations.Param;

import java.util.List;


/**
 * 贷款申请_附件Mapper接口
 * 
 * @author boman
 * @date 2024-04-24
 */
public interface LoanApplicationFjMapper 
{
    /**
     * 查询贷款申请_附件
     * 
     * @param fjId 贷款申请_附件主键
     * @return 贷款申请_附件
     */
    public LoanApplicationFj selectLoanApplicationFjByFjId(Long fjId);

    /**
     * 查询贷款申请_附件列表
     * 
     * @param loanApplicationFj 贷款申请_附件
     * @return 贷款申请_附件集合
     */
    public List<LoanApplicationFj> selectLoanApplicationFjList(LoanApplicationFj loanApplicationFj);

    /**
     * 根据贷款申请id查询所有附件
     * @param loanApplicationId
     * @return
     */
    public List<LoanApplicationFj> selectLoanApplicationFjByLoanApplicationId(Long loanApplicationId);

    /**
     * 新增贷款申请_附件
     * 
     * @param loanApplicationFj 贷款申请_附件
     * @return 结果
     */
    public int insertLoanApplicationFj(LoanApplicationFj loanApplicationFj);

    /**
     * 批量新增贷款申请_附件
     *
     * @param loanApplicationFjList 贷款申请_附件
     * @return 结果
     */
    public int batchLoanApplicationFj(List<LoanApplicationFj> loanApplicationFjList);

    /**
     * 修改贷款申请_附件
     * 
     * @param loanApplicationFj 贷款申请_附件
     * @return 结果
     */
    public int updateLoanApplicationFj(LoanApplicationFj loanApplicationFj);

    /**
     * 删除对应类型系统生成的pdf文件
     * @param loanApplicationFj
     * @return
     */
    public int deleteLoanApplicationFj(LoanApplicationFj loanApplicationFj);

    /**
     * 删除贷款申请_附件
     * 
     * @param fjId 贷款申请_附件主键
     * @return 结果
     */
    public int deleteLoanApplicationFjByFjId(Long fjId);

    /**
     * 批量删除贷款申请_附件
     * 
     * @param fjIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLoanApplicationFjByFjIds(Long[] fjIds);

    /**
     * 根据贷款申请id删除所有附件
     * @param loanApplicationId
     * @return
     */
    public int deleteLoanApplicationFjByLoanApplicationId(Long loanApplicationId);

    public int deleteLoanApplicationFjByLoanApplicationIdAndType(@Param("loanApplicationId") Long loanApplicationId,@Param("type") String[] type);
    public int deleteLoanApplicationFjByLoanApplicationIdAndBigType(@Param("loanApplicationId") Long loanApplicationId);
    public List<LoanApplicationFj> selectLoanApplicationFjByLoanApplicationIdAndType(@Param("loanApplicationId") Long loanApplicationId,@Param("type") String[] type);


    LoanApplicationFj ewmList(LoanApplicationFj loanApplicationFj);
}
